#!/usr/bin/perl
#
# Copyright (c) 2001, 2002, 2003 David Merrill <david@lupercalia.net>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
use Wt2Db;
$WT = new Wt2Db;

$buffer = 'foo bar

=Section|section=

paragraph

==Subsection|subsection==

paragraph


=Namespaces=

==MailTo==

[[mailto:david@lupercalia.net]]
[[mailto:david@lupercalia.net|David Merrill]]

==HTTP==

[[http://www.tldp.org]]
[[http://www.tldp.org|The Linux Documentation Project]]

*one
    **two
    **two, again
    /**

    ## ordered
    /#

    **two once more
    **two yet again
/*


Foo

';

$outbuf = '';

foreach $line (split /\n/, $buffer) {
	$WT->ProcessLine($line);
}
$WT->ProcessEnd();
$outbuf = $WT->Buffer();
print $outbuf;
